@@ -240,7 +240,7 @@ def bootstrap_field(field, **kwargs):
 @register.inclusion_tag("bootstrap_toolkit/button.html")
 def bootstrap_button(text, **kwargs):
     """
-    Render pagination for a page
+    Render a button
     """
     button_type = kwargs.get('type', '')
     button_size = kwargs.get('size', '')
@@ -255,13 +255,13 @@ def bootstrap_button(text, **kwargs):
         button_class += ' btn-' + button_size
     if button_disabled:
         button_class += ' disabled'
-    # Build icon classes
+        # Build icon classes
     icon_class = ''
     if button_icon:
         icon_class = 'icon-' + button_icon
         if button_type and button_type != 'link':
             icon_class += ' icon-white'
-    # Return context for template
+            # Return context for template
     return {
         'text': text,
         'url': kwargs.get('url', '#'),
@@ -270,6 +270,19 @@ def bootstrap_button(text, **kwargs):
     }
 
 
+@register.inclusion_tag("bootstrap_toolkit/icon.html")
+def bootstrap_icon(icon, **kwargs):
+    """
+    Render an icon
+    """
+    icon_class = 'icon-' + icon
+    if kwargs.get('inverse'):
+        icon_class += ' icon-white'
+    return {
+        'icon_class': icon_class,
+    }
+
+
 @register.inclusion_tag("bootstrap_toolkit/pagination.html")
 def bootstrap_pagination(page, **kwargs):
     """
@@ -280,7 +293,7 @@ def bootstrap_pagination(page, **kwargs):
     return get_pagination_context(**pagination_kwargs)
 
 
-def get_pagination_context(page, pages_to_show=11, url=None, extra=None):
+def get_pagination_context(page, pages_to_show=11, url=None, size=None, align=None, extra=None):
     """
     Generate Bootstrap pagination context from a page object
     """
@@ -339,6 +352,14 @@ def get_pagination_context(page, pages_to_show=11, url=None, extra=None):
         url += unicode(extra) + u'&'
     if url:
         url = url.replace(u'?&', u'?')
+    # Set CSS classes, see http://twitter.github.io/bootstrap/components.html#pagination
+    pagination_css_classes = ['pagination']
+    if size in ['small', 'large', 'mini']:
+        pagination_css_classes.append('pagination-%s' % size)
+    if align == 'center':
+        pagination_css_classes.append('pagination-centered')
+    elif align == 'right':
+        pagination_css_classes.append('pagination-right')
     # Build context object
     return {
         'bootstrap_pagination_url': url,
@@ -349,4 +370,5 @@ def get_pagination_context(page, pages_to_show=11, url=None, extra=None):
         'pages_shown': pages_shown,
         'pages_back': pages_back,
         'pages_forward': pages_forward,
+        'pagination_css_classes': ' '.join(pagination_css_classes),
     }
